@@ -23,8 +23,7 @@ from ..repository import multiplex
 from ..repository.util import SimpleTree, get_virtual_repos
 from ..restrictions import boolean, packages
 from ..util import parserestrict
-from ..util.commandline import (ArgumentParser, StoreRepoObject,
-                                convert_to_restrict)
+from ..util.commandline import ArgumentParser, StoreRepoObject, convert_to_restrict
 
 argparser = ArgumentParser(description=__doc__, script=(__file__, __name__))
 subparsers = argparser.add_subparsers(description='cleaning applets')
@@ -343,7 +342,7 @@ dist = subparsers.add_parser(
 dist_opts = dist.add_argument_group('distfile options')
 @dist.bind_final_check
 def _dist_validate_args(parser, namespace):
-    distdir = namespace.domain.fetcher.distdir
+    distdir = namespace.domain.distdir
     repo = namespace.repo
     if repo is None:
         repo = multiplex.tree(*get_virtual_repos(namespace.domain.source_repos, False))
