@@ -1,9 +1,8 @@
 from pkgcore.scripts import pclean
 from pkgcore.test.scripts.helpers import ArgParseMixin
-from snakeoil.test import TestCase
 
 
-class CommandlineTest(TestCase, ArgParseMixin):
+class TestCommandline(ArgParseMixin):
 
     _argparser = pclean.argparser
 
